@@ -35,11 +35,11 @@
  **
  **/
 
-// $Id: EnrichmentMapVisualStyle.java 533 2010-12-20 19:37:52Z risserlin $
-// $LastChangedDate: 2010-12-20 14:37:52 -0500 (Mon, 20 Dec 2010) $
-// $LastChangedRevision: 533 $
+// $Id: EnrichmentMapVisualStyle.java 541 2011-01-05 20:45:37Z risserlin $
+// $LastChangedDate: 2011-01-05 15:45:37 -0500 (Wed, 05 Jan 2011) $
+// $LastChangedRevision: 541 $
 // $LastChangedBy: risserlin $
-// $HeadURL: svn+ssh://risserlin@server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/tags/v1.00_cytoscape2.8.0/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/EnrichmentMapVisualStyle.java $
+// $HeadURL: svn+ssh://risserlin@server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/tags/v1.00_cytoscape2.7.0/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/EnrichmentMapVisualStyle.java $
 
 package org.baderlab.csplugins.enrichmentmap;
 
@@ -156,27 +156,17 @@ public class EnrichmentMapVisualStyle {
      * @param prefix - prefix to be appended to each of the attribute names
      */
     private void createEdgeAppearance(CyNetwork network, String prefix){
-        EdgeAppearanceCalculator edgeAppCalc = new EdgeAppearanceCalculator(vs.getDependency());
+        EdgeAppearanceCalculator edgeAppCalc = new EdgeAppearanceCalculator();
 
         //set the default edge appearance
         EdgeAppearance edgeAppear = new EdgeAppearance();
         edgeAppear.set(VisualPropertyType.EDGE_COLOR, new Color(100,200,000) );
         edgeAppCalc.setDefaultAppearance(edgeAppear);
 
-        ContinuousMapping continuousMapping_edgewidth;
-        try{
-            continuousMapping_edgewidth = new ContinuousMapping((new Integer(1)).getClass(),prefix + EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT);
-
-         }  catch (java.lang.NoSuchMethodError nsme ){
-            continuousMapping_edgewidth = new ContinuousMapping(1, ObjectMapping.EDGE_MAPPING);
-            continuousMapping_edgewidth.setControllingAttributeName(prefix + EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT, network, false);
-
-        }
-
         //Continous Mapping - set edge line thickness based on the number of genes in the overlap
         //ContinuousMapping continuousMapping_edgewidth = new ContinuousMapping((new Integer(1)).getClass(),prefix + EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT);
-        //ContinuousMapping continuousMapping_edgewidth = new ContinuousMapping(1, ObjectMapping.EDGE_MAPPING);
-        //continuousMapping_edgewidth.setControllingAttributeName(prefix + EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT, network, false);
+        ContinuousMapping continuousMapping_edgewidth = new ContinuousMapping(1, ObjectMapping.EDGE_MAPPING);
+        continuousMapping_edgewidth.setControllingAttributeName(prefix + EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT, network, false);
         Interpolator numTonum2 = new LinearNumberToNumberInterpolator();
         continuousMapping_edgewidth.setInterpolator(numTonum2);
 
@@ -220,7 +210,7 @@ public class EnrichmentMapVisualStyle {
         BoundaryRangeValues bv3i = new BoundaryRangeValues(max_phenotype1, max_phenotype1, max_phenotype1);
 
 
-        NodeAppearanceCalculator nodeAppCalc = new NodeAppearanceCalculator(vs.getDependency());
+        NodeAppearanceCalculator nodeAppCalc = new NodeAppearanceCalculator();
 
         //set the default node appearance
         NodeAppearance nodeAppear = new NodeAppearance();
@@ -232,12 +222,7 @@ public class EnrichmentMapVisualStyle {
         nodeAppCalc.setDefaultAppearance(nodeAppear);
         
         // Passthrough Mapping - set node label
-        PassThroughMapping pm;
-        try{
-           pm = new PassThroughMapping(new String(), prefix + EnrichmentMapVisualStyle.FORMATTED_NAME);
-        } catch (RuntimeException e){
-            pm = new PassThroughMapping(new String("label").getClass(), prefix + EnrichmentMapVisualStyle.FORMATTED_NAME);
-        }
+        PassThroughMapping pm = new PassThroughMapping(new String(), prefix + EnrichmentMapVisualStyle.FORMATTED_NAME);
 
 
         Calculator nlc = new BasicCalculator(prefix +"nodeLabel",
@@ -245,18 +230,9 @@ public class EnrichmentMapVisualStyle {
                nodeAppCalc.setCalculator(nlc);
 
 
-        ContinuousMapping continuousMapping_size;
-        try{
-            continuousMapping_size = new ContinuousMapping(new Integer(1).getClass(),prefix+ EnrichmentMapVisualStyle.GS_SIZE_DATASET1);
-        } catch (java.lang.NoSuchMethodError nsme ){
-            continuousMapping_size = new ContinuousMapping(1, ObjectMapping.EDGE_MAPPING);
-            continuousMapping_size.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.GS_SIZE_DATASET1, network, false);
-                  }
-
-
         //Continuous Mapping - set node size based on the size of the geneset
-        //ContinuousMapping continuousMapping_size = new ContinuousMapping(new Integer(1).getClass(),prefix+ EnrichmentMapVisualStyle.GS_SIZE_DATASET1);
-        //continuousMapping_size.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.GS_SIZE_DATASET1, network, false);
+        ContinuousMapping continuousMapping_size = new ContinuousMapping(35, ObjectMapping.NODE_MAPPING);
+        continuousMapping_size.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.GS_SIZE_DATASET1, network, false);
         Interpolator numTonum = new LinearNumberToNumberInterpolator();
         continuousMapping_size.setInterpolator(numTonum);
 
@@ -273,19 +249,9 @@ public class EnrichmentMapVisualStyle {
 
         if(params.isTwoDatasets()){
 
-            ContinuousMapping continuousMapping_size_dataset2;
-            try{
-
-                continuousMapping_size_dataset2 = new ContinuousMapping(new Integer(1).getClass(),prefix + EnrichmentMapVisualStyle.GS_SIZE_DATASET2);
-
-           } catch (java.lang.NoSuchMethodError nsme ){
-                continuousMapping_size_dataset2 = new ContinuousMapping(1, ObjectMapping.EDGE_MAPPING);
-                continuousMapping_size_dataset2.setControllingAttributeName(prefix + EnrichmentMapVisualStyle.GS_SIZE_DATASET2, network, false);
-            }
-
             //Continuous Mapping - set node size based on the size of the geneset
-            //ContinuousMapping continuousMapping_size_dataset2 = new ContinuousMapping(new Integer(1).getClass(),prefix + EnrichmentMapVisualStyle.GS_SIZE_DATASET2);
-            //continuousMapping_size_dataset2.setControllingAttributeName(prefix + EnrichmentMapVisualStyle.GS_SIZE_DATASET2, network, false);
+            ContinuousMapping continuousMapping_size_dataset2 = new ContinuousMapping(35, ObjectMapping.NODE_MAPPING);
+		continuousMapping_size_dataset2.setControllingAttributeName(prefix + EnrichmentMapVisualStyle.GS_SIZE_DATASET2, network, false);
             Interpolator numTonum3 = new LinearNumberToNumberInterpolator();
             continuousMapping_size_dataset2.setInterpolator(numTonum3);
 
@@ -300,22 +266,10 @@ public class EnrichmentMapVisualStyle {
              nodeAppCalc.setCalculator(nodelineSizeCalculator);
 
 
-            ContinuousMapping continuousMapping_width_col;
-            try{
-                continuousMapping_width_col = new ContinuousMapping(Color.WHITE.getClass(),prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET2);
-
-           } catch (java.lang.NoSuchMethodError nsme ){
-                continuousMapping_width_col = new ContinuousMapping(Color.WHITE, ObjectMapping.EDGE_MAPPING);
-                continuousMapping_width_col.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET2, network, false);
-
-                }
-
-
-
             //Continuous Mapping - set node line colour based on the sign of the ES score of second dataset
             //Color scale and mapper used by node colour and node line colour
-            //ContinuousMapping continuousMapping_width_col = new ContinuousMapping(Color.WHITE.getClass(),prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET2);
-            //continuousMapping_width_col.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET2, network, false);
+            ContinuousMapping continuousMapping_width_col = new ContinuousMapping(Color.WHITE, ObjectMapping.NODE_MAPPING);
+            continuousMapping_width_col.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET2, network, false);
             Interpolator numToColor2 = new LinearNumberToColorInterpolator();
             continuousMapping_width_col.setInterpolator(numToColor2);
 
@@ -337,17 +291,10 @@ public class EnrichmentMapVisualStyle {
         }
 
         //Continuous Mapping - set node colour based on the sign of the ES score of first dataset
-        ContinuousMapping continuousMapping;
-        try{
-            continuousMapping = new ContinuousMapping(Color.WHITE.getClass(),prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET1);
-                    
-         } catch (java.lang.NoSuchMethodError nsme ){
-            continuousMapping = new ContinuousMapping(Color.WHITE,ContinuousMapping.NODE_MAPPING);
-            continuousMapping.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET1, network, false);
-
-            }
-
-        Interpolator numToColor = new LinearNumberToColorInterpolator();
+        ContinuousMapping continuousMapping = new ContinuousMapping(Color.WHITE, ObjectMapping.NODE_MAPPING);  
+	  continuousMapping.setControllingAttributeName(prefix+ EnrichmentMapVisualStyle.COLOURING_DATASET1, network, false);
+        
+Interpolator numToColor = new LinearNumberToColorInterpolator();
         continuousMapping.setInterpolator(numToColor);
 
          // Set the attribute point values associated with the boundary values
